/*
** iplog_scan.h - iplog scan/flood detector data.
** Copyright (C) 1999 Odin <odin@numb.org>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License, version 2,
** as published by the Free Software Foundation.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
*/

#ifndef __IPLOG_SCAN_H
#define __IPLOG_SCAN_H

#define SCAN_TSIZE	128
#define SCAN_MAXENT	512

#define PS_THOLD	15
#define NS_THOLD	10
#define FS_THOLD	10
#define XS_THOLD	10
#define UDP_THOLD	15
#define SMURF_THOLD	25
#define PING_THOLD	15

#define PS_TIMEOUT		50
#define NS_TIMEOUT		50
#define FS_TIMEOUT		50
#define XS_TIMEOUT		50
#define UDP_TIMEOUT		50
#define SMURF_TIMEOUT	50
#define PING_TIMEOUT	50

#define SCAN_PORT	0
#define SCAN_NULL	1
#define SCAN_FIN	2
#define SCAN_XMAS	3
#define SCAN_UDP	4
#define SCAN_SMURF	5
#define SCAN_PING	6
#define SCAN_TOTAL	7

#ifndef DEF_ONLY

struct scan_data {
	struct scan_data *next;
	addr_t addr;
	struct scan_t {
		u_short count;
		bool logged;
		time_t expire;
		u_long bytes;
		pthread_mutex_t lock;
	} type[SCAN_TOTAL];
	rwlock_t lock;
};

struct scan_info {
	u_char *name;
	bool (*resolv)(void);
	u_long timeout;
	u_long threshold;
};

#endif

bool check_scan(u_char, addr_t, u_long);
void destroy_scan_table(void);
void expire_scans(void);

#endif
